@@ -4,13 +4,13 @@ package WWW::SourceForge::Project;
 use WWW::Mechanize;
 
 use vars qw($VERSION);
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 sub new {
     my ($class,$pname) = @_;
     my $url = _projurl($pname);
     my $proj;
-    my $wa  = WWW::Mechanize->new( autochcheck => 1);
+    my $wa  = WWW::Mechanize->new( autocheck => 1);
     $wa->get($url);
     my $content = $wa->content;
     # Project description
@@ -51,6 +51,14 @@ sub new {
     }
     $proj->{Admin} = \@admin;
 
+    # Find important links
+    my %links;
+    $links{home} = $wa->uri;
+    $links{developers} = ($wa->find_link(text_regex => qr/View Members/))->url;
+
+    $proj->{links} = \%links;
+    $proj->{_wa}   = $wa;
+    $proj->{members} = {};
     return bless($proj,$class);
 }
 
@@ -62,6 +70,39 @@ sub Admin {
     return wantarray? @$admin : $admin ;
 }
 
+sub Member {
+    my($self,$param) = @_;
+    my $wa   = WWW::Mechanize->new;
+    $wa->get($self->{links}->{home});
+    $wa->follow_link(url=>$self->{links}->{developers});
+    my $content = $wa->content;
+
+    my $members = $self->{members};
+    $members = $self->{members} = {} if ($param->{refresh});
+    return $members if(keys %$members);
+
+    while ($content =~ m{<tr>\s+<td>(.+?)</td>\s+<td.+?><a href="/users/(\w+?)/">\w+?</a>.*?</td>\s+<td.+?>(.*?)</td>\s+<td.+?><A href=".+?">(.+?)</td>\s+<td.+?>\s+</tr>}g) {
+        my ($realName,$loginname,$position,$email) = ($1,$2,$3,$4);
+        $email =~ s/\s+at\s+/@/;
+        $position =~ s/\s*\(.+\)\s*//; # strip inline comments.
+        $position =~ s/^\s+//;
+        $position ||= 'No specific role';
+        if ($realName =~ m{<A.+?>(.+?)</A}) {
+            $realName =$1;
+        }
+        push @{$members->{$position}||=[]} ,
+          {
+           realName  => $realName,
+           loginName => $loginname,
+           position  => $position,
+           email     => $email,
+          };
+    }
+
+    $self->{members} = $members;
+    return $self->{members};
+}
+
 sub Tracker {
     my $s = shift;
     my $r;
